@@ -8,7 +8,7 @@ _NO_FUNC = object()
 
 
 __all__ = ['App', '__version__']
-__version__ = '0.2'
+__version__ = '0.3'
 
 
 class App(object):
@@ -20,6 +20,7 @@ class App(object):
 
     def __init__(self, *args, **kwargs):
         self._parser = ArgumentParser(*args, **kwargs)
+        self._global_args = []
         self._subparsers = self._parser.add_subparsers(title="Subcommands")
         self._pending_args = []
         self._defaults = {}
@@ -29,6 +30,7 @@ class App(object):
 
         All arguments are passed on to :py:meth:`ArgumentParser.add_argument`.
         """
+        self._global_args.append((args, kwargs))
         return self._parser.add_argument(*args, **kwargs)
 
     def defaults(self, **kwargs):
@@ -62,6 +64,11 @@ class App(object):
             subparser = self._subparsers.add_parser(
                     subcommand, *parser_args, **parser_kwargs)
 
+            # Add global arguments to subcommand as well so that they
+            # can be given after the subcommand on the CLI.
+            for global_args, global_kwargs in self._global_args:
+                subparser.add_argument(*global_args, **global_kwargs)
+
             # Add any pending arguments
             for args, kwargs in self._pending_args:
                 subparser.add_argument(*args, **kwargs)
@@ -83,9 +90,11 @@ class App(object):
         return wrapper
 
     def cmd_arg(self, *args, **kwargs):
-        """Decorator to specify an command line argument for a subcommand.
+        """Decorator to specify a command line argument for a subcommand.
 
         All arguments are passed on to :py:meth:`ArgumentParser.add_argument`.
+
+        Note: this function must be used in conjunction with .cmd().
         """
 
         # TODO: perhaps add a 'group' argument to cmd_arg() that
@@ -109,6 +118,8 @@ class App(object):
         subcommands.
 
         All arguments are passed on to :py:meth:`ArgumentParser.set_defaults`.
+
+        Note: this function must be used in conjunction with .cmd().
         """
         if len(kwargs) == 1 and callable(list(kwargs.values())[0]):
             raise TypeError("defaults() decorator requires arguments, "
